@@ -8,14 +8,15 @@ from pathlib import Path
 
 import nox
 
-nox.options.sessions = ["lint", "tests"]
+nox.needs_version = ">=2025.02.09"
+nox.options.default_venv_backend = "uv|virtualenv"
 
-PYTHON_ALL_VERSIONS = ["3.7", "3.8", "3.9", "3.10", "3.11", "3.12", "pypy3.7", "pypy3.8", "pypy3.9"]
+PYPROJECT = nox.project.load_toml("pyproject.toml")
+PYTHON_VERSIONS = nox.project.python_versions(PYPROJECT)
+
+PYTHON_ALL_VERSIONS = [*PYTHON_VERSIONS, "pypy3.8", "pypy3.9", "pypy3.10", "pypy3.11"]
 MSVC_ALL_VERSIONS = {"2017", "2019", "2022"}
 
-if os.environ.get("CI", None):
-    nox.options.error_on_missing_interpreters = True
-
 
 @nox.session
 def lint(session):
@@ -43,18 +44,18 @@ def tests(session: nox.Session) -> None:
             contained = "1" if version in known_MSVC else "0"
             env[f"SKBUILD_TEST_FIND_VS{version}_INSTALLATION_EXPECTED"] = contained
 
-    numpy = [] if "pypy" in session.python or "3.12" in session.python else ["numpy"]
+    numpy = [] if "pypy" in session.python or sys.platform == "cygwin" else ["numpy"]
     install_spec = "-e.[test,cov,doctest]" if "--cov" in posargs else ".[test,doctest]"
     if "--cov" in posargs:
         posargs.append("--cov-config=pyproject.toml")
 
     # Latest versions may break things, so grab them for testing!
-    session.install("-U", "setuptools", "wheel")
+    session.install("-U", "setuptools", "wheel", "virtualenv")
     session.install(install_spec, *numpy)
     session.run("pytest", *posargs, env=env)
 
 
-@nox.session
+@nox.session(default=False)
 def pylint(session):
     """
     Run PyLint.
@@ -64,7 +65,7 @@ def pylint(session):
     session.run("pylint", "skbuild", *session.posargs)
 
 
-@nox.session
+@nox.session(default=False)
 def docs(session):
     """
     Build the docs. Use "-R" to rebuild faster. Check options with "-- -h".
@@ -85,7 +86,7 @@ def docs(session):
         session.run("python", "-m", "http.server", "8000", "-d", "_build/html")
 
 
-@nox.session
+@nox.session(default=False)
 def build(session):
     """
     Make an SDist and a wheel.
@@ -95,7 +96,7 @@ def build(session):
     session.run("python", "-m", "build")
 
 
-@nox.session(reuse_venv=True)
+@nox.session(reuse_venv=True, default=False)
 def build_api_docs(session: nox.Session) -> None:
     """
     Build (regenerate) API docs.
@@ -114,7 +115,7 @@ def build_api_docs(session: nox.Session) -> None:
     )
 
 
-@nox.session(reuse_venv=True)
+@nox.session(reuse_venv=True, default=False)
 def downstream(session: nox.Session) -> None:
     """
     Build a downstream project.
