@@ -13,6 +13,7 @@ import json
 import os
 import os.path
 import platform
+import shlex
 import shutil
 import stat
 import sys
@@ -250,7 +251,7 @@ def _parse_setuptools_arguments(
 
     return (
         display_only,
-        dist.help_commands,  # type: ignore[attr-defined]
+        bool(dist.help_commands),
         dist.commands,
         dist.hide_listing,  # type: ignore[attr-defined]
         dist.force_cmake,  # type: ignore[attr-defined]
@@ -319,9 +320,7 @@ def _package_data_contain_module(module: tuple[str, str, str], package_data: Map
     # and the entry in package_data would look like this:
     #
     #   {'foo.bar' : ['module.py']}
-    if strip_package(package.split("."), module_file) in package_data[package]:
-        return True
-    return False
+    return strip_package(package.split("."), module_file) in package_data[package]
 
 
 def _should_run_cmake(commands: Sequence[str], cmake_with_sdist: bool) -> bool:
@@ -344,9 +343,7 @@ def _should_run_cmake(commands: Sequence[str], cmake_with_sdist: bool) -> bool:
 
     if expected_commands & given_commands:
         return True
-    if "sdist" in given_commands and cmake_with_sdist:
-        return True
-    return False
+    return bool("sdist" in given_commands and cmake_with_sdist)
 
 
 def _save_cmake_spec(args: Mapping[str, Any]) -> None:
@@ -450,7 +447,7 @@ def setup(
     try:
         _check_skbuild_parameters(cmake_install_dir, cmake_source_dir)
     except SKBuildError as ex:
-        import traceback  # pylint: disable=import-outside-toplevel
+        import traceback  # noqa: PLC0415
 
         print("Traceback (most recent call last):", file=sys.stderr)
         traceback.print_tb(sys.exc_info()[2])
@@ -508,7 +505,7 @@ def setup(
             print('Arguments following a "--" are passed directly to CMake (e.g. -DMY_VAR:BOOL=TRUE).')
             print('Arguments following a second "--" are passed directly to the build tool.')
             print(flush=True)
-        return setuptools.setup(**kw)
+        return setuptools.setup(**kw)  # type: ignore[no-any-return]
 
     developer_mode = "develop" in commands or build_ext_inplace
 
@@ -517,10 +514,10 @@ def setup(
     package_data = {k: copy.copy(v) for k, v in kw.get("package_data", {}).items()}
 
     py_modules = kw.get("py_modules", [])
-    new_py_modules = {py_module: False for py_module in py_modules}
+    new_py_modules = dict.fromkeys(py_modules, False)
 
     scripts = kw.get("scripts", [])
-    new_scripts = {script: False for script in scripts}
+    new_scripts = dict.fromkeys(scripts, False)
 
     data_files = {(parent_dir or "."): set(file_list) for parent_dir, file_list in kw.get("data_files", [])}
 
@@ -533,14 +530,14 @@ def setup(
     # Setting target from command takes precedence
     # cmake_install_target_from_setup has the default 'install',
     # so cmake_install_target would never be empty.
-    if cmake_install_target_from_command:
-        cmake_install_target = cmake_install_target_from_command
-    else:
-        cmake_install_target = cmake_install_target_from_setup
+    cmake_install_target = cmake_install_target_from_command or cmake_install_target_from_setup
 
     # Parse CMAKE_ARGS
-    env_cmake_args = os.environ["CMAKE_ARGS"].split() if "CMAKE_ARGS" in os.environ else []
-    env_cmake_args = [s for s in env_cmake_args if "CMAKE_INSTALL_PREFIX" not in s]
+    if "CMAKE_ARGS" in os.environ:
+        env_cmake_args = shlex.split(os.environ["CMAKE_ARGS"])
+        env_cmake_args = [s for s in env_cmake_args if "CMAKE_INSTALL_PREFIX" not in s]
+    else:
+        env_cmake_args = []
 
     # Since CMake arguments provided through the command line have more weight
     # and when CMake is given multiple times a argument, only the last one is
@@ -622,7 +619,7 @@ def setup(
 
                 # A local "cmake" folder can be imported by mistake, keep going if it is
                 # pylint: disable-next=import-outside-toplevel
-                from cmake import CMAKE_BIN_DIR
+                from cmake import CMAKE_BIN_DIR  # noqa: PLC0415
 
                 for executable_name in ("cmake", "cpack", "ctest"):
                     executable = os.path.join(CMAKE_BIN_DIR, executable_name)
@@ -673,7 +670,7 @@ def setup(
     except SKBuildGeneratorNotFoundError as ex:
         sys.exit(ex)  # type: ignore[arg-type]
     except SKBuildError as ex:
-        import traceback  # pylint: disable=import-outside-toplevel
+        import traceback  # noqa: PLC0415
 
         print("Traceback (most recent call last):", file=sys.stderr)
         traceback.print_tb(sys.exc_info()[2])
@@ -776,7 +773,7 @@ def setup(
 
     print(flush=True)
 
-    return setuptools.setup(**kw)
+    return setuptools.setup(**kw)  # type: ignore[no-any-return]
 
 
 def _collect_package_prefixes(package_dir: dict[str, str], packages: list[Any | str]) -> list[Any | tuple[str, str]]:
