@@ -82,7 +82,7 @@ def test_make_without_configure_fails(capfd):
         CMaker().make()
     _, err = capfd.readouterr()
     assert "An error occurred while building with CMake." in str(excinfo.value)
-    assert "Error: could not load cache" in err
+    assert "Error: could not load cache" in err or "Error: not a CMake build directory (missing CMakeCache.txt)" in err
 
 
 @pytest.mark.parametrize("configure_with_cmake_source_dir", [True, False])
@@ -93,7 +93,7 @@ def test_make(configure_with_cmake_source_dir, capfd):
         src_dir.join("CMakeLists.txt").write(
             textwrap.dedent(
                 """
-            cmake_minimum_required(VERSION 3.5.0)
+            cmake_minimum_required(VERSION 3.5...3.26)
             project(foobar NONE)
             file(WRITE "${CMAKE_BINARY_DIR}/foo.txt" "# foo")
             install(FILES "${CMAKE_BINARY_DIR}/foo.txt" DESTINATION ".")
@@ -110,7 +110,7 @@ def test_make(configure_with_cmake_source_dir, capfd):
             config_kwargs = {}
             if configure_with_cmake_source_dir:
                 config_kwargs["cmake_source_dir"] = str(src_dir)
-            env = cmkr.configure(**config_kwargs)
+            env = cmkr.configure(**config_kwargs)  # type: ignore[arg-type]
             cmkr.make(env=env)
 
         messages = ["Project has been installed"]
@@ -140,7 +140,7 @@ def test_make_with_install_target(install_target, capfd):
         tmp_dir.join("CMakeLists.txt").write(
             textwrap.dedent(
                 """
-            cmake_minimum_required(VERSION 3.5.0)
+            cmake_minimum_required(VERSION 3.5...3.26)
             project(foobar NONE)
             file(WRITE "${CMAKE_BINARY_DIR}/foo.txt" "# foo")
             file(WRITE "${CMAKE_BINARY_DIR}/runtime.txt" "# runtime")
@@ -190,7 +190,7 @@ def test_configure_with_cmake_args(capfd):
         tmp_dir.join("CMakeLists.txt").write(
             textwrap.dedent(
                 """
-            cmake_minimum_required(VERSION 3.5.0)
+            cmake_minimum_required(VERSION 3.5...3.26)
             project(foobar NONE)
             # Do not complain about missing arguments passed to the main
             # project
