@@ -12,7 +12,7 @@ HELLO_NUMPY = os.path.join(DIR, "samples/hello-numpy")
 BASE = os.path.dirname(DIR)
 
 
-@pytest.mark.isolated()
+@pytest.mark.isolated
 @pytest.mark.skipif(sys.platform.startswith("cygwin"), reason="Needs release of scikit-build to make cmake work")
 @pytest.mark.skipif(
     platform.python_implementation() == "PyPy" and sys.version_info >= (3, 9),
