@@ -10,6 +10,7 @@ import os
 import pprint
 import sys
 import textwrap
+from collections.abc import Sequence
 from unittest.mock import patch
 
 import py.path
@@ -57,7 +58,7 @@ def test_distribution_is_pure(distribution_type, tmpdir):
         cmakelists_txt = tmpdir.join("CMakeLists.txt")
         cmakelists_txt.write(
             """
-            cmake_minimum_required(VERSION 3.5.0)
+            cmake_minimum_required(VERSION 3.5...3.26)
             project(test NONE)
             install(CODE "execute_process(
               COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
@@ -113,7 +114,7 @@ def test_cmake_args_keyword(cmake_args, capfd):
     tmp_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(test NONE)
         message(STATUS "VAR[${VAR}]")
         message(STATUS "VAR_WITH_SPACE[${VAR_WITH_SPACE}]")
@@ -194,7 +195,7 @@ def test_cmake_install_dir_keyword(cmake_install_dir, expected_failed, error_cod
     tmp_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(banana NONE)
         file(WRITE "${CMAKE_BINARY_DIR}/__init__.py" "")
         install(FILES "${CMAKE_BINARY_DIR}/__init__.py" DESTINATION ".")
@@ -220,7 +221,7 @@ def test_cmake_install_dir_keyword(cmake_install_dir, expected_failed, error_cod
 
     assert failed == expected_failed
     if failed:
-        if error_code_type == str:
+        if error_code_type is str:
             assert message == "error: package directory '{}' does not exist".format(
                 os.path.join(CMAKE_INSTALL_DIR(), "banana")
             )
@@ -253,7 +254,7 @@ def test_cmake_with_sdist_keyword(cmake_with_sdist, capfd):
     tmp_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(test NONE)
         install(CODE "execute_process(
           COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
@@ -295,7 +296,7 @@ def test_cmake_minimum_required_version_keyword():
     tmp_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(test NONE)
         install(CODE "execute_process(
           COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
@@ -315,7 +316,7 @@ def test_cmake_minimum_required_version_keyword():
         assert "CMake version 99.98.97 or higher is required." in message
 
 
-@pytest.mark.deprecated()
+@pytest.mark.deprecated
 @pytest.mark.filterwarnings("ignore:setuptools.installer is deprecated:Warning")
 @pytest.mark.skipif(
     os.environ.get("CONDA_BUILD", "0") == "1",
@@ -345,15 +346,13 @@ def test_setup_requires_keyword_include_cmake(mocker, capsys):
             license="MIT",
             setup_requires=[{setup_requires}]
         )
-        """.format(
-                setup_requires=",".join(["'%s'" % package for package in setup_requires])
-            )
+        """.format(setup_requires=",".join([f"'{package}'" for package in setup_requires]))
         )
     )
     tmp_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(test NONE)
         install(CODE "execute_process(
           COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
@@ -421,7 +420,7 @@ def test_script_keyword(distribution_type, capsys, caplog):
         tmp_dir.join("CMakeLists.txt").write(
             textwrap.dedent(
                 """
-            cmake_minimum_required(VERSION 3.5.0)
+            cmake_minimum_required(VERSION 3.5...3.26)
             project(foo NONE)
             file(WRITE "${CMAKE_BINARY_DIR}/foo.py" "# foo.py")
             file(WRITE "${CMAKE_BINARY_DIR}/bar.py" "# bar.py")
@@ -502,7 +501,7 @@ def test_py_modules_keyword(distribution_type, capsys, caplog):
         tmp_dir.join("CMakeLists.txt").write(
             textwrap.dedent(
                 """
-            cmake_minimum_required(VERSION 3.5.0)
+            cmake_minimum_required(VERSION 3.5...3.26)
             project(foobar NONE)
             file(WRITE "${CMAKE_BINARY_DIR}/foo.py" "# foo.py")
             file(WRITE "${CMAKE_BINARY_DIR}/bar.py" "# bar.py")
@@ -542,7 +541,6 @@ def test_py_modules_keyword(distribution_type, capsys, caplog):
         ([""], "file.py", "file.py"),
         ([], "foo/file.py", "foo/file.py"),
         (["foo"], "", ""),
-        (["foo"], "", ""),
         (["foo"], "foo/file.py", "file.py"),
         (["foo"], "foo\\file.py", "file.py"),
         (["foo", "bar"], "foo/file.py", "foo/file.py"),
@@ -726,7 +724,7 @@ def test_setup_inputs(
     src_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(hybrid NONE)
         set(build_dir ${{CMAKE_BINARY_DIR}})
 
@@ -774,22 +772,25 @@ def test_setup_inputs(
     )
 
     # List path types: 'c', 'cm', 'h', 'p' or 'pm'
+    path_types: Sequence[str]
     try:
-        path_types = list(
-            zip(
-                *filter(
-                    lambda i: i[1],
-                    [
-                        ("c", has_cmake_package),
-                        ("cm", has_cmake_module),
-                        ("h", has_hybrid_package),
-                        ("p", has_pure_package),
-                        ("pm", has_pure_module),
-                    ],
+        path_types = next(
+            iter(
+                zip(
+                    *filter(
+                        lambda i: i[1],
+                        [
+                            ("c", has_cmake_package),
+                            ("cm", has_cmake_module),
+                            ("h", has_hybrid_package),
+                            ("p", has_pure_package),
+                            ("pm", has_pure_module),
+                        ],
+                    )
                 )
             )
-        )[0]
-    except IndexError:
+        )
+    except StopIteration:
         path_types = []
 
     def select_paths(annotated_paths):
@@ -828,8 +829,8 @@ def test_setup_inputs(
             ("p", "pure/data/pure.dat"),
         ]
     ):
-        assert _type in ["p", "pm", "h"]
-        root = package_base if (_type == "p" or _type == "pm") else cmake_source_dir
+        assert _type in {"p", "pm", "h"}
+        root = package_base if _type in {"p", "pm"} else cmake_source_dir
         tmp_dir.ensure(os.path.join(root, path))
 
     # Do not call the real setup function. Instead, replace it with
@@ -840,9 +841,9 @@ def test_setup_inputs(
     def _pprint(desc, value=None):
         print(
             "-----------------\n"
-            "{}:\n"
+            f"{desc}:\n"
             "\n"
-            "{}\n".format(desc, pprint.pformat(setup_kw.get(desc, {}) if value is None else value, indent=2))
+            f"{pprint.pformat(setup_kw.get(desc, {}) if value is None else value, indent=2)}\n"
         )
 
     with execute_setup_py(tmp_dir, ["build"], disable_languages_test=True):
@@ -1003,7 +1004,7 @@ def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys, caplog):
     cmake_src_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(test NONE)
         file(WRITE "${CMAKE_BINARY_DIR}/apple.py" "# apple.py")
         file(WRITE "${CMAKE_BINARY_DIR}/banana.py" "# banana.py")
@@ -1075,7 +1076,7 @@ def test_zip_safe_default(zip_safe, mocker):
     tmp_dir.join("CMakeLists.txt").write(
         textwrap.dedent(
             """
-        cmake_minimum_required(VERSION 3.5.0)
+        cmake_minimum_required(VERSION 3.5...3.26)
         project(test NONE)
         install(CODE "execute_process(
           COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
